<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../src/widgets/daboutdialog.cpp" line="191"/>
        <source>Acknowledgements</source>
        <translation>Erkenningen</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="712"/>
        <source>Version: %1</source>
        <translation>Versie: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="716"/>
        <source>%1 is released under %2</source>
        <translation>%1 is uitgebracht onder de %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="530"/>
        <source>Black</source>
        <translation>Zwart</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="533"/>
        <source>White</source>
        <translation>Wit</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="536"/>
        <source>Dark Gray</source>
        <translation>Donkergrijs</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="539"/>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="542"/>
        <source>Light Gray</source>
        <translation>Lichtgrijs</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="545"/>
        <source>Red</source>
        <translation>Rood</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="548"/>
        <source>Green</source>
        <translation>Groen</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="551"/>
        <source>Blue</source>
        <translation>Blauw</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="554"/>
        <source>Cyan</source>
        <translation>Groenblauw</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="557"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="560"/>
        <source>Yellow</source>
        <translation>Geel</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="563"/>
        <source>Dark Red</source>
        <translation>Donkerrood</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="566"/>
        <source>Dark Green</source>
        <translation>Donkergroen</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="569"/>
        <source>Dark Blue</source>
        <translation>Donkerblauw</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="572"/>
        <source>Dark Cyan</source>
        <translation>Donkergroenblauw</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="575"/>
        <source>Dark Magenta</source>
        <translation>Donkermagenta</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="578"/>
        <source>Dark Yellow</source>
        <translation>Donkergeel</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Bevestigen</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Druk op een nieuwe sneltoets</translation>
    </message>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/widgets/dsimplelistview.cpp" line="1235"/>
        <source>No search result</source>
        <translation>Geen zoekresultaten</translation>
    </message>
    <message>
        <location filename="../src/widgets/private/settings/content.cpp" line="189"/>
        <source>Restore Defaults</source>
        <translation>Standaardwaarden herstellen</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/widgets/private/settings/shortcutedit.cpp" line="119"/>
        <source>Please enter a new shortcut</source>
        <translation>Druk op een nieuwe sneltoets</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="449"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="456"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="463"/>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
</TS>